/*
 *  arch-tag: Header for Rhythmbox DBus remoting
 *
 *  Copyright (C) 2004 Colin Walters <walters@verbum.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 */

#ifndef __RB_REMOTE_DBUS_H
#define __RB_REMOTE_DBUS_H

#include "rb-remote-proxy.h"

G_BEGIN_DECLS

#define RB_TYPE_REMOTE_DBUS (rb_remote_dbus_get_type ())
#define RB_REMOTE_DBUS(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), RB_TYPE_REMOTE_DBUS, RBRemoteDBus))
#define RB_REMOTE_DBUS_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), RB_TYPE_REMOTE_DBUS, RBRemoteDBusClass))
#define RB_IS_REMOTE_DBUS(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), RB_TYPE_REMOTE_DBUS))
#define RB_IS_REMOTE_DBUS_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), RB_TYPE_REMOTE_DBUS))
#define RB_REMOTE_DBUS_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), RB_TYPE_REMOTE_DBUS, RBRemoteDBusClass))

typedef struct RBRemoteDBusPrivate RBRemoteDBusPrivate;

typedef struct
{
        GObject parent;

	RBRemoteDBusPrivate *priv;
} RBRemoteDBus;

typedef struct
{
        GObjectClass parent_class;

	void (*shuffle_changed) (RBRemoteDBus *dbus, gboolean shuffle);
	void (*repeat_changed) (RBRemoteDBus *dbus, gboolean repeat);
	void (*playing_changed) (RBRemoteDBus *dbus, gboolean playing);
	/* void (*playing_song_changed) (RBRemoteDBus *dbus, something *song); */
} RBRemoteDBusClass;

typedef enum
{
	RB_REMOTE_DBUS_ERROR_REQUEST_NAME_FAILURE,
} RBRemoteDBusError;

#define RB_REMOTE_DBUS_ERROR rb_remote_dbus_error_quark ()

GQuark rb_remote_dbus_error_quark (void);

GType rb_remote_dbus_get_type (void);

RBRemoteDBus * rb_remote_dbus_new (void);

void rb_remote_dbus_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
void rb_remote_dbus_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);

gboolean rb_remote_dbus_activate (RBRemoteDBus *bonobo);

gboolean rb_remote_dbus_acquire (RBRemoteDBus *bonobo,
				 RBRemoteProxy *proxy,
				 GError **error);


gboolean rb_remote_dbus_quit (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_grab_focus (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_handle_uri (RBRemoteDBus *dbus, const char *uri, GError **error);

gboolean rb_remote_dbus_get_playing (RBRemoteDBus *dbus, gboolean *playing, GError **error);
gboolean rb_remote_dbus_play_pause (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_play (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_pause (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_jump_next (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_jump_previous (RBRemoteDBus *dbus, GError **error);
gboolean rb_remote_dbus_get_playing_time (RBRemoteDBus *dbus, gulong *time, GError **error);
gboolean rb_remote_dbus_set_playing_time (RBRemoteDBus *dbus, gulong time, GError **error);
gboolean rb_remote_dbus_get_playing_song_uri (RBRemoteDBus *dbus, char **uri, guint32 *pants, GError **error); 
gboolean rb_remote_dbus_get_song_info (RBRemoteDBus *dbus, const char *uri, char **title, 
				       char **artist, char **genre, 
				       char **album, long *track_number, 
				       long *duration, long *bitrate, 
				       long *filesize, long *rating, 
				       long *play_count, long *last_played, 
				       long *disc_number, GError **error);

gboolean rb_remote_dbus_get_shuffle (RBRemoteDBus *dbus, gboolean *shuffle, GError **error);
gboolean rb_remote_dbus_set_shuffle (RBRemoteDBus *dbus, gboolean shuffle, GError **error);
gboolean rb_remote_dbus_toggle_shuffle (RBRemoteDBus *dbus, GError **error);

gboolean rb_remote_dbus_get_repeat (RBRemoteDBus *dbus, gboolean *repeat, GError **error);
gboolean rb_remote_dbus_set_repeat (RBRemoteDBus *dbus, gboolean repeat, GError **error);
gboolean rb_remote_dbus_toggle_repeat (RBRemoteDBus *dbus, GError **error);

G_END_DECLS

#endif /* __RB_REMOTE_DBUS_H */
